package XML::Toolkit::Trait::NoXML;
use Moose::Role;
use namespace::autoclean;

1;
__END__

=head1 NAME

XML::Toolkit::Trait::NoXML - A class to ...

=head1 VERSION

This documentation refers to version 0.01.

=head1 SYNOPSIS

use XML::Toolkit::Trait::NoXML;

=head1 DESCRIPTION

The XML::Toolkit::Trait::NoXML class implements ...

=head1 SUBROUTINES / METHODS

=head1 DEPENDENCIES

Modules used, version dependencies, core yes/no

Moose::Role

=head1 NOTES

...

=head1 BUGS AND LIMITATIONS

None known currently, please email the author if you find any.

=head1 AUTHOR

Chris Prather (perigrin@domain.tld)

=head1 LICENCE

Copyright 2009 by Chris Prather.

This software is free.  It is licensed under the same terms as Perl itself.

=cut
